#####################################################################
#	Input															#
#		*myDataFrame												#
#####################################################################
library(ape)
library(vegan)
library(psych)
library(dendextend)
library(ggdendro)
library(pvclust)
library(ggplot2)
library(ggnewscale)
library(wesanderson)

myDataFrame = read.csv("Cerrejonisuchus_CompleteDataset.csv", check.names = FALSE)

#We fix a random seed, so that all the results (e.g. permanovas) are reproducible
set.seed(69420)

#We use the following thresholds:
# .3 & .4 for Cerrejonisuchus_CompleteDataset
# .1 & .4 for Dyro Body

colCompletenessThreshold <- .3
rowCompletenessThreshold <- .4

myRealDataExportName <- 'CerrejonisuchusOctober2020'
myGraphExportName <- paste0(myRealDataExportName,"_Threshold",colCompletenessThreshold,rowCompletenessThreshold)

#####################################################################
#	Main Script														#
#####################################################################

myFilteredData <- myDataFrame #3rd column is clade
myFilteredData <- myFilteredData[,colMeans(is.na(myFilteredData))  <= 1-colCompletenessThreshold] 
myFilteredData <- myFilteredData[rowMeans(is.na(myFilteredData)) <= 1-rowCompletenessThreshold,]

if(dim(myFilteredData)[2] == 4)
	stop("Not enough data, try to change completeness threshold")

myRealData <- myFilteredData[,5:dim(myFilteredData)[2]]   
myRealData <- sapply(myRealData,as.numeric)
rownames(myRealData)<- paste(myFilteredData[,1],"_",myFilteredData[,2],sep="")
myIndividuals <- myFilteredData[,1]
myClades <- myFilteredData[,3]
myThanatocoenosis <- myFilteredData[,4]

print(paste("Amount of missing data:",100*mean(is.na(myRealData)),"%")) #% of missing data

######### Scaling #######

data.s<-scale(myRealData) 
distance<-dist(data.s)
print(paste("Amount of missing data in distance matrix:",100*mean(is.na(distance)),"%")) #% of missing data in distance

###### Cluster ########   # Creates a tree to represent the ecomorpho groups that exist in our matrix data.s
clust_result <- pvclust(as.data.frame(t(data.s)), method.dist="eu", method.hclust="ward.D2", use.cor="pairwise.complete.obs", nboot=1000, r=seq(0.5,10,by=.5)) # "euclidean distances" for method distance and "ward" for clustering method r= different size of data subsets 50% to 1000%
plot(clust_result)

###### Significance tests ######## 


#=====================================================#
#===================== PERMANOVA =====================#   Looking for significative differences between morphologic groups
#=====================================================#

#Number of groups we want from the cluster dendrogram results
cut <- 3
cut_result <- cutree(clust_result$hclust,k=cut)

#test the statistical significance of the clusters (the groups were defined above using the "cut" variable and cutree function)
cut_result_dataframe <- as.data.frame(cut_result) 
permanova <- adonis2(distance~cut_result,data=cut_result_dataframe,permutations=1000) 
permanova
#write.table(permanova, file=paste("permanova_clusters_",region,".csv",sep=""))

#=====================================================#
#===================== PERMANOVA =====================#  Looking for significative differences between cladistic groups  
#=====================================================#

######### Creation of a cladistic list ############   to feed to the permanova to see if there are any significant differences between the phylo clades based on our ecomorpo data
myCladeGroups <- as.data.frame(myClades) 
rownames(myCladeGroups) <- rownames(myRealData) 

permanova <- adonis2(distance~myClades,data=myCladeGroups,permutations=1000) 
permanova





#Select the ordination method that will be used to compute the morphospaces. Use "#" in front of unselected method
ordin_method <- "PCoA"
#ordin_method <- "NMDS"

################ PCoA #################

pcoa <- pcoa(distance,correction="cailliez")
biplot(pcoa)

################ NMDS #################

#NMDS
nmds <- metaMDS(distance,k=2,trymax=100) #k=2 dimensions
#pdf(paste("Figures/SUPP_INFO_NMDS_stressplot_",region,".pdf",sep=""), width=7, height=7)
stressplot(nmds)
#dev.off()

############################### COLORING SETTINGS FOR PHYLOFIG #####################################

#cladeLabels <- c("Dyrosauridae","Thalattosuchia","Crocodilia","Pholidosauridae or Dyrosauridae") #When 4 clades
cladeLabels <- c("Dyrosauridae","Thalattosuchia","Crocodilia") #When 3 clades
cladeColors <- wes_palette(name = "Darjeeling1", type = "continuous")

names(cladeColors)<- cladeLabels
col_clades <- scale_colour_manual(name = "clade",values = cladeColors) 

################################### CONVEX HULL #########################################

#Select the ordination method that will be used to compute the morphospaces. Use "#" in front of unselected method
ordin_method <- "PCoA"
#ordin_method <- "NMDS"

#Standardise data and temporarily homogenise axes labels and add phylogenetic information
if (ordin_method=="PCoA"){
  to_plot <- as.data.frame(pcoa$vectors[,1:2]) # ! If there was a correction applied during the processing (ex: bc there are negative values): USE vectors.cor[,1:2] INSTEAD
} else if (ordin_method=="NMDS"){
  to_plot <- as.data.frame(nmds$points)
} else {
  print("error in ordination method used")
}

colnames(to_plot) <- c("Axis1","Axis2")
to_plot$clade <- myClades 
to_plot$Thanatocoenosis <- myThanatocoenosis


#Draw convex hulls using the Split-Apply-Combine strategy
if (ordin_method=="PCoA"){
	splitData <- split(to_plot, to_plot$clade) 
} else if (ordin_method=="NMDS") {
	splitData <- split(to_plot, to_plot$clade)
}

cHull <- lapply(splitData, function(df){
  df[chull(df), ]  # chull computes convex hulls for each subgroup.
})
cHull <- do.call(rbind, cHull) #combines the coordinates of the points (i.e. taxa) needed to draw the convex hull (i.e. only the extremes ones)
cHull

#Visualise the morphospace using ggplot
phylo_fig <- ggplot(data = to_plot,aes(x = Axis1, y = Axis2))+
  geom_polygon(data = cHull,aes(x = Axis1, y = Axis2, color= clade, fill = clade),alpha = 1/2) + #color = contour des polygones ; fill = remplissage des polygones, alpha = transparence 
  scale_fill_manual(values=cladeColors)+ 
  geom_point(aes(color=clade)) +
  scale_color_manual(values=cladeColors)+ 
  geom_text(aes(label=rownames(to_plot),color=clade))+
  coord_fixed(ratio=1,xlim=c(min(to_plot[,1])*1.3,max(to_plot[,1])*1.3),ylim=c(min(to_plot[,2])*1.3,max(to_plot[,2])*1.3)) 
if(ordin_method=="PCoA"){ 
  phylo_fig <- phylo_fig+labs(title = paste("Ratio",ordin_method), 
							x = paste("Principal Coordinates", colnames(to_plot)[1],"(",100*(round(pcoa$values[1,3],digits=3)),"%)"),  #3rd column of pcoa$values is either rel_corr_eig or Relative_eig
							y = paste("Principal Coordinates", colnames(to_plot)[2],"(",100*(round(pcoa$values[2,3],digits=3)),"%)"))
} else if (ordin_method=="NMDS"){
  phylo_fig <- phylo_fig+labs(title = paste("Ratio –",ordin_method), 
							x = "NMDS1", 
							y = "NMDS2")
} else {
  print("wrong ordination method used")
}
phylo_fig

#ggsave(paste("SUPP_INFO_PhyloMorphospace_",myGraphExportName,"_",ordin_method,".pdf",sep=""),device="pdf",units="mm",width=240,height=240) 




############################### COLORING SETTINGS FOR ECOFIG #####################################

thanatocoenosisLabels <- c("Unknown","Pelagic","Marine/Coastal","Aquatic/Amphibious","Terrestrial")
thanatocoenosisColors <- wes_palette(name = "Rushmore1", type = "continuous")

names(thanatocoenosisColors)<- thanatocoenosisLabels
col_thanato <- scale_colour_manual(name = "Thanatocoenosis",values = thanatocoenosisColors)

################################### ECOFIG #########################################

#Draw convex hulls using the Split-Apply-Combine strategy

if (ordin_method=="PCoA"){
	splitData <- split(to_plot, to_plot$Thanatocoenosis) 
} else if (ordin_method=="NMDS") {
	splitData <- split(to_plot, to_plot$Thanatocoenosis)
}

cHull <- lapply(splitData, function(df){
  df[chull(df), ]  # chull computes convex hulls for each subgroup.
})
cHull <- do.call(rbind, cHull) #combines the coordinates of the points (i.e. taxa) needed to draw the convex hull (i.e. only the extremes ones)
cHull

#Visualise the morphospace using ggplot
eco_fig <- ggplot(data = to_plot,aes(x = Axis1, y = Axis2))+
  geom_polygon(data = cHull,aes(x = Axis1, y = Axis2, color= Thanatocoenosis, fill = Thanatocoenosis),alpha = 1/2) + 
  scale_fill_manual(values=thanatocoenosisColors)+ 
  geom_point(aes(color=Thanatocoenosis)) +
  scale_color_manual(values=thanatocoenosisColors)+  
  geom_text(aes(label=rownames(to_plot),color=Thanatocoenosis))+
  coord_fixed(ratio=1,xlim=c(min(to_plot[,1])*1.3,max(to_plot[,1])*1.3),ylim=c(min(to_plot[,2])*1.3,max(to_plot[,2])*1.3))
if(ordin_method=="PCoA"){  
  eco_fig <- eco_fig+labs(title = paste("Ratio",ordin_method), 
							x = paste("Principal Coordinates", colnames(to_plot)[1],"(",100*(round(pcoa$values[1,3],digits=3)),"%)"),  #3rd column of pcoa$values is either rel_corr_eig or Relative_eig
							y = paste("Principal Coordinates", colnames(to_plot)[2],"(",100*(round(pcoa$values[2,3],digits=3)),"%)"))
} else if (ordin_method=="NMDS"){
  eco_fig <- eco_fig+labs(title = paste("Ratio –",ordin_method), 
							x = "NMDS1", 
							y = "NMDS2")
} else {
  print("wrong ordination method used")
}
eco_fig
#ggsave(paste("SUPP_INFO_Morphospace_Thanatocoenosis_",myGraphExportName,"_",ordin_method,".pdf",sep=""),device="pdf",units="mm",width=240,height=240) #sauvegarde le graphe affiché

###############################################################################################################################################
########################################################   PHYLOECOFIG  #######################################################################
###############################################################################################################################################

#thanatocoenosisColors <- wes_palette(name = "Rushmore1", type = "continuous")
thanatocoenosisColors<- c("#000000","#0000ff","#ffff00","#00ff00","#000000")
#thanatocoenosisShapes<- c(8,17,18,15,19)
thanatocoenosisShapes<- c(8,2,5,0,1)
thanatocoenosisSizes<- c(1,2,3,2,2)

if (ordin_method=="PCoA"){
	splitData <- split(to_plot, to_plot$clade) 
} else if (ordin_method=="NMDS") {
	splitData <- split(to_plot, to_plot$clade)
}

cHull <- lapply(splitData, function(df){
  df[chull(df), ]  # chull computes convex hulls for each subgroup.
})
cHull <- do.call(rbind, cHull) #combines the coordinates of the points (i.e. taxa) needed to draw the convex hull (i.e. only the extremes ones)
cHull

###Fig with point size depending on thanatocoenosis
#Visualise the morphospace using ggplot
phyloEco_fig <- ggplot(data = to_plot,aes(x = Axis1, y = Axis2))+
  geom_polygon(data = cHull,aes(x = Axis1, y = Axis2,  color = clade, fill = clade),alpha = 1/2) +  
  scale_fill_manual(values=cladeColors)+ 
  scale_color_manual(values=cladeColors)+  
  new_scale_color() +
  geom_point(data=to_plot,aes(color=clade,shape=Thanatocoenosis), size=3, stroke=1.5, fill = NA) + 
  scale_shape_manual(values=thanatocoenosisShapes, limits=thanatocoenosisLabels)+  #shape of points
  scale_color_manual(values=cladeColors)+  #color of points
  #scale_size_manual(values=thanatocoenosisSizes, limits=thanatocoenosisLabels)#+  #size of points
  new_scale_color() +
  geom_text(aes(label=rownames(to_plot),color=clade))+
  scale_color_manual(values=cladeColors)+  #colorise point
  coord_fixed(ratio=1,xlim=c(min(to_plot[,1])*1.3,max(to_plot[,1])*1.3),ylim=c(min(to_plot[,2])*1.3,max(to_plot[,2])*1.3)) 
if(ordin_method=="PCoA"){ 
  phyloEco_fig <- phyloEco_fig+labs(title = paste("Ratio",ordin_method), 
							x = paste("Principal Coordinates", colnames(to_plot)[1],"(",100*(round(pcoa$values[1,3],digits=3)),"%)"),  #3rd column of pcoa$values is either rel_corr_eig or Relative_eig
							y = paste("Principal Coordinates", colnames(to_plot)[2],"(",100*(round(pcoa$values[2,3],digits=3)),"%)"))
} else if (ordin_method=="NMDS"){
  phyloEco_fig <- phyloEco_fig+labs(title = paste("Ratio –",ordin_method), 
							x = "NMDS1", 
							y = "NMDS2")
} else {
  print("wrong ordination method used")
}
phyloEco_fig

#ggsave(paste("SUPP_INFO_PhyloEcoMorphospace_Thanatocoenosis_",myGraphExportName,"_",ordin_method,".pdf",sep=""),device="pdf",units="mm",width=240,height=240) #sauvegarde le graphe affiché


