#####################################################################
#	Input															#
#		*myDataFrame												#
#####################################################################
library(ape)
library(vegan)
library(psych)
library(dendextend)
library(ggdendro)
library(pvclust)
library(ggplot2)

myDataFrame = read.csv("Cerrejonisuchus_SKULLDataset.csv", check.names = FALSE)


colCompletenessThresold <- .25
rowCompletenessThresold <- .5

myRealDataExportName <- 'DyrosauridaeSkullOctober2020'
myGraphExportName <- paste0(myRealDataExportName,"_Threshold",colCompletenessThresold,rowCompletenessThresold)
myGraphExportName


library(xtable)
library(data.table)
myDataFrame[,1:2]  #The total list of individuals before applying thresholds
IndividualList <- myDataFrame[,1:2]


#####################################################################
#	Main Script														#
#####################################################################

myFilteredData <- myDataFrame 

myFilteredData <- myFilteredData[,colMeans(is.na(myFilteredData))  <= 1-colCompletenessThresold]
myFilteredData <- myFilteredData[rowMeans(is.na(myFilteredData)) <= 1-rowCompletenessThresold,]

myRealData <- myFilteredData[,6:dim(myFilteredData)[2]]
myRealData <- sapply(myRealData,as.numeric)
rownames(myRealData)<- paste(myFilteredData[,1],"_",myFilteredData[,2],sep="")
myIndividuals <- myFilteredData[,1]
myClades <- myFilteredData[,3]
myThanatocoenosis <- myFilteredData[,4]
absoluteSkullSize <- myFilteredData[,5]

paste("Amount of missing data:",100*mean(is.na(myRealData)),"%") #% of missing data

############ EXPORTING DATAFRAME ###########


write.csv(myRealData, paste0(myRealDataExportName,'.csv'), row.names = TRUE) #row.names = TRUE so we are keeping the row names, is going to be saved in said directory

######### Scaling #######

data.s<-scale(myRealData) 
distance<-dist(data.s)
paste("Amount of missing data in distance matrix:",100*mean(is.na(distance)),"%") #% of missing data in distance

###### Cluster ########
clust_result <- pvclust(as.data.frame(t(data.s)), method.dist="eu", method.hclust="ward.D2", use.cor="pairwise.complete.obs", nboot=1000, r=seq(0.5,10,by=.5)) # "euclidean distances" for method distance and "ward" for clustering method r= different size of data subsets 50% to 1000%

plot(clust_result)

###### Test significatif ########

#Number of groups you want from the cluster dendrogram results
cut <- 3
cut_result <- cutree(clust_result$hclust,k=cut)
cut_result

#=====================================================#
#===================== PERMANOVA =====================#
#=====================================================#

#test the statistical significance of the clusters (the groups were defined above using the "cut" variable and cutree function)
permanova <- adonis2(distance~cut_result,data=as.data.frame(cut_result),permutations=1000) 
permanova


#Select the ordination method that will be used to compute the morphospaces. Use "#" in front of unselected method
ordin_method <- "PCoA"
#ordin_method <- "NMDS"


################ PCoA #################


#PCoA   Combinaisons linéaires de variables
pcoa <- pcoa(distance,correction="cailliez")
biplot(pcoa)

################ NMDS #################

#NMDS
nmds <- metaMDS(distance,k=2,trymax=100) #k=2 dimensions

stressplot(nmds)


############################### COLORING SETTINGS #####################################

cladeLabels <- c("Dyrosauridae","Thalattosuchia","Crocodilia") #When 3 clades

#Use ggplot2 to visualise the cluster dendrogram
cladeColors <- c('#f54b1a','#01abe9', '#ff952c','#CD5C5C'); #When 4 clades
#cladeColors <- c('#f54b1a','#01abe9', '#ff952c'); #When 3 clades
#names(cladeColors)<-c("Dyrosauridae","Thalattosuchia","Crocodilia")
names(cladeColors)<- cladeLabels
col_clades <- scale_colour_manual(name = "clade",values = cladeColors) #name = réfère à un nom de colonne

#clusterColors <- c('#f54b1a','#01abe9', '#ff952c'); #couleurs différentes en fonction du cluster
#names(clusterColors) <-  c(cladeLabels)
#col_clusters <- scale_colour_manual(name = "cluster",values = clusterColors)
#fill_clusters <- scale_fill_manual(name = "cluster",values = clusterColors)

################################### CONVEX HULL #########################################


#Select the ordination method that will be used to compute the morphospaces. Use "#" in front of unselected method
ordin_method <- "PCoA"
#ordin_method <- "NMDS"

#Standardise data and temporarily homogenise axes labels and add phylogenetic information
if (ordin_method=="PCoA"){
  to_plot <- as.data.frame(pcoa$vectors[,1:2]) # ! If there was a correction applied during the processing (ex: bc there are negative values): USE vectors.cor[,1:2] INSTEAD
} else if (ordin_method=="NMDS"){
  to_plot <- as.data.frame(nmds$points)
} else {
  print("error in ordination method used")
}

colnames(to_plot) <- c("Axis1","Axis2")
to_plot$clade <- myClades 
to_plot$Thanatocoenosis <- myThanatocoenosis 
#Draw convex hulls using the Split-Apply-Combine strategy
#splitData <- split(to_plot[,c(1,2,4)], to_plot$clade)

if (ordin_method=="PCoA"){
	splitData <- split(to_plot, to_plot$clade)
} else if (ordin_method=="NMDS") {
	splitData <- split(to_plot, to_plot$clade)
}

cHull <- lapply(splitData, function(df){
  df[chull(df), ]  # chull computes convex hulls for each subgroup.
})
cHull <- do.call(rbind, cHull) #combines the coordinates of the points (i.e. taxa) needed to draw the convex hull (i.e. only the extremes ones)
cHull


#Visualise the morphospace using ggplot
eco_fig <- ggplot(data = to_plot,aes(x = Axis1, y = Axis2))+
  geom_polygon(data = cHull,aes(x = Axis1, y = Axis2, color= clade, fill = clade),alpha = 1/2) + 
  scale_fill_manual(values=cladeColors)+ 
  geom_point(aes(color=clade)) +
  scale_color_manual(values=cladeColors)+  
  geom_text(aes(label=rownames(to_plot),color=clade))+
  coord_fixed(ratio=1,xlim=c(min(to_plot[,1])*1.3,max(to_plot[,1])*1.3),ylim=c(min(to_plot[,2])*1.3,max(to_plot[,2])*1.3))
if(ordin_method=="PCoA"){  
  eco_fig <- eco_fig+labs(title = paste("Ratio",ordin_method), 
							x = paste("Principal Coordinates", colnames(to_plot)[1],"(",100*(round(pcoa$values[1,3],digits=3)),"%)"),  #3rd column of pcoa$values is either rel_corr_eig or Relative_eig
							y = paste("Principal Coordinates", colnames(to_plot)[2],"(",100*(round(pcoa$values[2,3],digits=3)),"%)"))
} else if (ordin_method=="NMDS"){
  eco_fig <- eco_fig+labs(title = paste("Ratio –",ordin_method), 
							x = "NMDS1", 
							y = "NMDS2")
} else {
  print("wrong ordination method used")
}
eco_fig
ggsave(paste("SUPP_INFO_Morphospace_Skull_",myGraphExportName,"_",ordin_method,".pdf",sep=""),device="pdf",units="mm",width=240,height=240) 




###############################################################################################################################################
########################################################   PHYLOECOFIG  #######################################################################
###############################################################################################################################################

library(ggplot2)
library(ggnewscale)


thanatocoenosisColors <- wes_palette(name = "Rushmore1", type = "continuous")
thanatocoenosisColors<- c("#000000","#0000ff","#ffff00","#00ff00","#000000")
thanatocoenosisShapes<- c(8,17,18,15,19)
thanatocoenosisSizes<- c(1,2,3,2,2)

if (ordin_method=="PCoA"){
	splitData <- split(to_plot, to_plot$clade)
} else if (ordin_method=="NMDS") {
	splitData <- split(to_plot, to_plot$clade)
}

cHull <- lapply(splitData, function(df){
  df[chull(df), ]  # chull computes convex hulls for each subgroup.
})
cHull <- do.call(rbind, cHull) #combines the coordinates of the points (i.e. taxa) needed to draw the convex hull (i.e. only the extremes ones)
cHull

###Fig with point size depending on thanatocoenosis
#Visualise the morphospace using ggplot
phyloEco_fig <- ggplot(data = to_plot,aes(x = Axis1, y = Axis2))+
  geom_polygon(data = cHull,aes(x = Axis1, y = Axis2,  color = clade, fill = clade),alpha = 1/2) + #color = contour des polygones ; fill = remplissage des polygones, alpha = transparence 
  scale_fill_manual(values=cladeColors)+ 
  scale_color_manual(values=cladeColors)+  
  new_scale_color() +
  geom_point(data=to_plot,aes(color=Thanatocoenosis,shape=Thanatocoenosis, size=absoluteSkullSize)) +
  scale_shape_manual(values=thanatocoenosisShapes, limits=thanatocoenosisDictionary)+  #shape of points
  scale_color_manual(values=thanatocoenosisColors, limits=thanatocoenosisDictionary)+  #color of points
  #scale_size_manual(values=absoluteSkullSize, limits=thanatocoenosisDictionary)+  #size of points
  new_scale_color() +
  geom_text(aes(label=rownames(to_plot),color=clade))+
  scale_color_manual(values=cladeColors)+  #colorise point
  coord_fixed(ratio=1,xlim=c(min(to_plot[,1])*1.3,max(to_plot[,1])*1.3),ylim=c(min(to_plot[,2])*1.3,max(to_plot[,2])*1.3))
if(ordin_method=="PCoA"){  
  phyloEco_fig <- phyloEco_fig+labs(title = paste("Ratio",ordin_method), 
							x = paste("Principal Coordinates", colnames(to_plot)[1],"(",100*(round(pcoa$values[1,3],digits=3)),"%)"),  #3rd column of pcoa$values is either rel_corr_eig or Relative_eig
							y = paste("Principal Coordinates", colnames(to_plot)[2],"(",100*(round(pcoa$values[2,3],digits=3)),"%)"))
} else if (ordin_method=="NMDS"){
  phyloEco_fig <- phyloEco_fig+labs(title = paste("Ratio –",ordin_method), 
							x = "NMDS1", 
							y = "NMDS2")
} else {
  print("wrong ordination method used")
}
phyloEco_fig
ggsave(paste("SUPP_INFO_PhyloEcoMorphospace_Thanatocoenosis_",myGraphExportName,"_",ordin_method,".pdf",sep=""),device="pdf",units="mm",width=240,height=240) 

